unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, Spectrum3DLibraryDefs, BASS, StdCtrls, ExtCtrls, ComCtrls;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    Button1: TButton;
    OpenDialog1: TOpenDialog;
    Timer1: TTimer;
    TrackBar1: TTrackBar;
    TrackBar2: TTrackBar;
    TrackBar3: TTrackBar;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure Panel1Resize(Sender: TObject);
    procedure TrackBar1Change(Sender: TObject);
    procedure TrackBar2Change(Sender: TObject);
    procedure TrackBar3Change(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;
  Sprectrum3D: Pointer;

implementation

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
    //* Init our library
    InitSpectrum3DLibrary;
    //* Initialize BASS
	if (HIWORD(BASS_GetVersion) <> BASSVERSION) then begin
		MessageDlg('BASS version 2.4 was not loaded!', mtError, [mbOk], 0);
		Halt;
	end;
	if not BASS_Init(-1, 44100, 0, Handle, nil) then begin
		MessageDlg('Cannot start default audio device!', mtError, [mbOk], 0);
	end;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
    Spectrum3D_Free(Sprectrum3D);
    BASS_Stop;
    BASS_Free;
    FreeSpectrum3DLibrary;
end;

procedure TForm1.Button1Click(Sender: TObject);
var
    Params: TSpectrum3D_CreateParams;
begin
    if OpenDialog1.Execute then begin
        //* Set parent control
        Params.ParentHandle := Panel1.Handle;
        //* Use True for modern 3D GFX cards
        Params.HardwareVertexProcessing := False;
        //* Use antialiasing
        Params.AntiAliasing := True;
        //* Create our spectrum display
        Sprectrum3D := Spectrum3D_Create(Params);
        //* Create and set channel handle
        //* Below Delphi 2009
        //Spectrum3D_SetChannel(Sprectrum3D, BASS_StreamCreateFile(False, PChar(OpenDialog1.FileName), 0, 0, 0));
        //* Delphi 2009 and above
        Spectrum3D_SetChannel(Sprectrum3D, BASS_StreamCreateFile(False, PChar(OpenDialog1.FileName), 0, 0, BASS_UNICODE OR BASS_STREAM_AUTOFREE));
        //* Start playing and visualising
        BASS_ChannelPlay(Spectrum3D_GetChannel(Sprectrum3D), True);
    end;
end;

procedure TForm1.Timer1Timer(Sender: TObject);
begin
    //* Render a frame
    Spectrum3D_Render(Sprectrum3D);
end;

procedure TForm1.Panel1Resize(Sender: TObject);
begin
    //* In case the panel is resized realign the display
    Spectrum3D_ReAlign(Sprectrum3D, Panel1.Handle);
end;

procedure TForm1.TrackBar1Change(Sender: TObject);
var
    Params: TSpectrum3D_Settings;
begin
    //* Get all settings
    Params := Spectrum3D_GetParams(Sprectrum3D);
    //* Change setting
    Params.GFXZoom := TrackBar1.Position;
    //* Apply new settings
    Spectrum3D_SetParams(Sprectrum3D, Params);
end;

procedure TForm1.TrackBar2Change(Sender: TObject);
var
    Params: TSpectrum3D_Settings;
begin
    //* Get all settings
    Params := Spectrum3D_GetParams(Sprectrum3D);
    //* Change setting
    Params.GFXScroll := TrackBar2.Position;
    //* Apply new settings
    Spectrum3D_SetParams(Sprectrum3D, Params);
end;

procedure TForm1.TrackBar3Change(Sender: TObject);
var
    Params: TSpectrum3D_Settings;
begin
    //* Get all settings
    Params := Spectrum3D_GetParams(Sprectrum3D);
    //* Change setting
    Params.GFXAmplitude := TrackBar3.Position;
    //* Apply new settings
    Spectrum3D_SetParams(Sprectrum3D, Params);
end;

end.
