{******************************************************************************}
{*                                                                            *}
{*  Copyright (c) 2002, NVIDIA Corporation.                                   *}
{*                                                                            *}
{*  Files:    ICgFXEffect.h                                                   *}
{*  Content:  NVIDIA CgFX interface include files                             *}
{*                                                                            *}
{*  NVIDIA "Cg" Release 1.2 ObjectPascal adaptation by Alexey Barkovoy        *}
{*  E-Mail: clootie@ixbt.com                                                  *}
{*                                                                            *}
{*  Modified: 14-Mar-2004                                                     *}
{*                                                                            *}
{*  Latest version can be downloaded from:                                    *}
{*     http://clootie.narod.ru                                                *}
{*                                                                            *}
{******************************************************************************}
{                                                                              }
{ Obtained through: Joint Endeavour of Delphi Innovators (Project JEDI)        }
{                                                                              }
{ The contents of this file are used with permission, subject to the Mozilla   }
{ Public License Version 1.1 (the "License"); you may not use this file except }
{ in compliance with the License. You may obtain a copy of the License at      }
{ http://www.mozilla.org/MPL/MPL-1.1.html                                      }
{                                                                              }
{ Software distributed under the License is distributed on an "AS IS" basis,   }
{ WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for }
{ the specific language governing rights and limitations under the License.    }
{                                                                              }
{ Alternatively, the contents of this file may be used under the terms of the  }
{ GNU Lesser General Public License (the  "LGPL License"), in which case the   }
{ provisions of the LGPL License are applicable instead of those above.        }
{ If you wish to allow use of your version of this file only under the terms   }
{ of the LGPL License and not to allow others to use your version of this file }
{ under the MPL, indicate your decision by deleting  the provisions above and  }
{ replace  them with the notice and other provisions required by the LGPL      }
{ License.  If you do not delete the provisions above, a recipient may use     }
{ your version of this file under either the MPL or the LGPL License.          }
{                                                                              }
{ For more information about the LGPL: http://www.gnu.org/copyleft/lesser.html }
{                                                                              }
{******************************************************************************}
(*********************************************************************NVMH3****
Path:  E:\Documents and Settings\sdomine\My Documents\CGFX_Beta_Runtime\include
File:  ICgFXEffect.h

Copyright NVIDIA Corporation 2002
TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THIS SOFTWARE IS PROVIDED
*AS IS* AND NVIDIA AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES, EITHER EXPRESS
OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE.  IN NO EVENT SHALL NVIDIA OR ITS SUPPLIERS
BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT, OR CONSEQUENTIAL DAMAGES
WHATSOEVER (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS,
BUSINESS INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR ANY OTHER PECUNIARY LOSS)
ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF NVIDIA HAS
BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.


Comments:




******************************************************************************)

//////////////////////////////////////////////////////////////////////////////
// HISTORY:
// 04-Mar-04 - Alexey Barkovoy:
//   - Updated to Release 1.2 of Cg toolkit (published 25-Feb-2004)

unit cgFX;

interface

uses
  Windows;

{$MINENUMSIZE 4}
{$ALIGN ON}

(*$HPPEMIT '#include "ICgFXEffect.h"' *)

const
  CgFX_DLL = 'CgFXab.dll';

const
  CGFX_MAX_DIMENSIONS = 4;
  {$EXTERNALSYM CGFX_MAX_DIMENSIONS}

//////////////////////////////////////////////////////////////////////////////
// Types /////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

type
  CGFXHANDLE = PAnsiChar;
  {$EXTERNALSYM CGFXHANDLE}
  TCgFXHandle = CGFXHANDLE;

  CgFXPARAMETERTYPE = (
    CgFXPT_UNKNOWN {= 0},
    CgFXPT_BOOL,
    CgFXPT_INT,
    CgFXPT_FLOAT,
    CgFXPT_DWORD,
    CgFXPT_STRING,

    CgFXPT_TEXTURE1D,
    CgFXPT_TEXTURE2D,
    CgFXPT_TEXTURERECT,
    CgFXPT_TEXTURECUBE,
    CgFXPT_TEXTURE3D,

    CgFXPT_SAMPLER1D,
    CgFXPT_SAMPLER2D,
    CgFXPT_SAMPLERRECT,
    CgFXPT_SAMPLERCUBE,
    CgFXPT_SAMPLER3D,

    CgFXPT_STRUCT

    // force 32-bit size enum
    //CgFXPT_FORCE_DWORD      = 0x7fffffff
  );
  {$EXTERNALSYM CgFXPARAMETERTYPE}
  TCgFXParameterType = CgFXPARAMETERTYPE;
  PCgFXParameterType = ^TCgFXParameterType;


  CgFXPARAMETERCLASS = (
    CgFXPC_SCALAR,
    CgFXPC_VECTOR,
    CgFXPC_MATRIX_ROWS,
    CgFXPC_MATRIX_COLUMNS,
    CgFXPC_OBJECT,
    CgFXPC_STRUCT

    //CgFXPC_FORCE_DWORD      = 0x7fffffff
  );
  {$EXTERNALSYM CgFXPARAMETERCLASS}
  TCgFXParameterClass = CgFXPARAMETERCLASS;
  PCgFXParameterClass = ^TCgFXParameterClass;


  PCgFXEffectDesc = ^TCgFXEffectDesc;
  CgFXEFFECT_DESC = packed record
    Creator: PAnsiChar;
    Parameters: LongWord; // Number of parameters
    Techniques: LongWord; // Number of techniques
    Functions: LongWord;  // Number of functions
  end;
  {$EXTERNALSYM CgFXEFFECT_DESC}
  TCgFXEffectDesc = CgFXEFFECT_DESC;

const
  // CgFXPARAMETER_DESC::Flags
  CGFX_PARAMETER_SHARED = 1;
  CGFX_PARAMETER_LITERAL = 2;
  CGFX_PARAMETER_ANNOTATION = 4;

type
  PCgFXParameterDesc = ^TCgFXParameterDesc;
  CgFXPARAMETER_DESC = packed record
    Name: PAnsiChar;                    // Parameter name.
    Semantic: PAnsiChar;                // Semantic meaning
    Class_: TCgFXParameterClass;
    Type_: TCgFXParameterType;          // Parameter type
    Dimension: array [0..CGFX_MAX_DIMENSIONS-1] of LongWord; //
    Rows, Columns, Elements: LongWord;
    Annotations: LongWord;              // Number of annotations.
    StructMembers: LongWord;
    Bytes: LongWord;                    // Total size in bytes
    Flags: DWORD;
  end;
  {$EXTERNALSYM CgFXPARAMETER_DESC}
  TCgFXParameterDesc = CgFXPARAMETER_DESC;


  PCgFXTechniqueDesc = ^TCgFXTechniqueDesc;
  CgFXTECHNIQUE_DESC = packed record
    Name: PAnsiChar;                        // Technique name
    Annotations: LongWord;
    Passes: LongWord;                       // Number of passes
  end;
  {$EXTERNALSYM CgFXTECHNIQUE_DESC}
  TCgFXTechniqueDesc = CgFXTECHNIQUE_DESC;


  PCgFXVarying = ^TCgFXVarying;
  CgFXVARYING = packed record
    Name: PAnsiChar;
    Resource: LongWord;
    Elements: LongWord;
  end;
  {$EXTERNALSYM CgFXVARYING}
  TCgFXVarying = CgFXVARYING;


  PCgFXSamplerInfo = ^TCgFXSamplerInfo;
  CgFXSAMPLER_INFO = packed record
    Type_: LongWord;
  end;
  {$EXTERNALSYM CgFXSAMPLER_INFO}
  TCgFXSamplerInfo = CgFXSAMPLER_INFO;


const
  MAX_CGFX_DECL_LENGTH = 16;

type
  PCgFXPassDesc = ^TCgFXPassDesc;
  CgFXPASS_DESC = packed record
    Name: PAnsiChar;
    Annotations: LongWord;
    VSVersion: DWORD;
    PSVersion: DWORD;
    VertexVaryingUsed: LongWord;
    VertexVarying: array[0..MAX_CGFX_DECL_LENGTH-1] of TCgFXVarying;
    FragmentVaryingUsed: LongWord;
    FragmentVarying: array[0..MAX_CGFX_DECL_LENGTH-1] of TCgFXVarying;
    PSSamplersUsed: LongWord;
    PSSamplers: array[0..15] of TCgFXSamplerInfo;
  end;
  {$EXTERNALSYM CgFXPASS_DESC}
  TCgFXPassDesc = CgFXPASS_DESC;


  CgFXMode = (
    CgFX_Unknown,
    CgFX_OpenGL,
    CgFX_Direct3D8,
    CgFX_Direct3D9
  );
  {$EXTERNALSYM CgFXMode}
  TCgFXMode = CgFXMode;
  PCgFXMode = ^TCgFXMode;


  //////////////////////////////////////////////////////////////////////////////
  // Base Effect ///////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////
  // base interface. extended by Effect and EffectCompiler.
  //////////////////////////////////////////////////////////////////////////////
  ICgFXBaseEffect = interface(IUnknown)
  //Clootie: Althrow original NVIDIA C++ class is not COM conpatible interface, but myself generated BorlandC++ one IS!!!
    function GetAnnotation(object_: TCgFXHandle; num: LongWord): TCgFXHandle; stdcall;
    function GetAnnotationByName(object_: TCgFXHandle; name: PAnsiChar): TCgFXHandle; stdcall;

    function GetParameter(parent: TCgFXHandle; index: LongWord): TCgFXHandle; stdcall;
    function GetParameterByName(parent: TCgFXHandle; name: PAnsiChar): TCgFXHandle; stdcall;
    function GetParameterBySemantic(parent: TCgFXHandle; name: PAnsiChar): TCgFXHandle; stdcall;
    function GetParameterElement(parent: TCgFXHandle; element: LongWord): TCgFXHandle; stdcall;

    function GetPass(technique: TCgFXHandle; index: LongWord): TCgFXHandle; stdcall;
    function GetPassByName(technique: TCgFXHandle; name: PAnsiChar): TCgFXHandle; stdcall;

    function GetTechnique(index: LongWord): TCgFXHandle; stdcall;
    function GetTechniqueByName(name: PAnsiChar): TCgFXHandle; stdcall;

    function GetDesc(out pDesc: TCgFXEffectDesc): HRESULT; stdcall;
    function GetParameterDesc(pParameter: TCgFXHandle; out pDesc: TCgFXParameterDesc): HRESULT; stdcall;

    function GetTechniqueDesc(pTechnique: TCgFXHandle; out pDesc: TCgFXTechniqueDesc): HRESULT; stdcall;
    function GetPassDesc(pPass: TCgFXHandle; out pDesc: TCgFXPassDesc): HRESULT; stdcall;

    function SetValue(pName: TCgFXHandle; pData: Pointer; Bytes: LongWord): HRESULT; stdcall;
    function GetValue(pName: TCgFXHandle; pData: Pointer; Bytes: LongWord): HRESULT; stdcall;

    function SetFloat(pName: TCgFXHandle; f: Single): HRESULT; stdcall;
    function GetFloat(pName: TCgFXHandle; out f: Single): HRESULT; stdcall;
    function GetFloatArray(pName: TCgFXHandle; f: PSingle; count: LongWord): HRESULT; stdcall;
    function SetFloatArray(pName: TCgFXHandle; const f: PSingle; count: LongWord): HRESULT; stdcall;

    function GetInt(pName: TCgFXHandle; out value: Integer): HRESULT; stdcall;
    function SetInt(pName: TCgFXHandle; value: Integer): HRESULT; stdcall;
    function GetIntArray(pName: TCgFXHandle; value: PInteger; count: LongWord): HRESULT; stdcall;
    function SetIntArray(pName: TCgFXHandle; const value: PInteger; count: LongWord): HRESULT; stdcall;

    function SetVector(pName: TCgFXHandle; const pVector: PSingle; vecSize: LongWord): HRESULT; stdcall;
    function GetVector(pName: TCgFXHandle; pVector: PSingle; vecSize: LongWord): HRESULT; stdcall;
    function SetVectorArray(pName: TCgFXHandle; const pVector: PSingle; vecSize: LongWord; count: LongWord): HRESULT; stdcall;
    function GetVectorArray(pName: TCgFXHandle; pVector: PSingle; vecSize: LongWord; count: LongWord): HRESULT; stdcall;

    function SetMatrix(pName: TCgFXHandle; const pMatrix: PSingle; nRows: LongWord; nCols: LongWord): HRESULT; stdcall;
    function GetMatrix(pName: TCgFXHandle; pMatrix: PSingle; nRows: LongWord; nCols: LongWord): HRESULT; stdcall;
    function SetMatrixArray(pName: TCgFXHandle; const pMatrix: PSingle; nRows: LongWord; nCols: LongWord; count: LongWord): HRESULT; stdcall;
    function GetMatrixArray(pName: TCgFXHandle; pMatrix: PSingle; nRows: LongWord; nCols: LongWord; count: LongWord): HRESULT; stdcall;

    function SetMatrixTranspose(pName: TCgFXHandle; const pMatrix: PSingle; nRows: LongWord; nCols: LongWord): HRESULT; stdcall;
    function GetMatrixTranspose(pName: TCgFXHandle; pMatrix: PSingle; nRows: LongWord; nCols: LongWord): HRESULT; stdcall;
    function SetMatrixTransposeArray(pName: TCgFXHandle; const pMatrix: PSingle; nRows: LongWord; nCols: LongWord; count: LongWord): HRESULT; stdcall;
    function GetMatrixTransposeArray(pName: TCgFXHandle; pMatrix: PSingle; nRows: LongWord; nCols: LongWord; count: LongWord): HRESULT; stdcall;

    function SetDWORD(pName: TCgFXHandle; dw: DWORD): HRESULT; stdcall;
    function GetDWORD(pName: TCgFXHandle; out dw: DWORD): HRESULT; stdcall;

    function SetBool(pName: TCgFXHandle; bvalue: BOOL): HRESULT; stdcall;
    function GetBool(pName: TCgFXHandle; out bvalue: BOOL): HRESULT; stdcall;
    function GetBoolArray(pName: TCgFXHandle; bvalue: PBOOL; count: LongWord): HRESULT; stdcall;
    function SetBoolArray(pName: TCgFXHandle; const bvalue: PBOOL; count: LongWord): HRESULT; stdcall;

    function SetString(pName: TCgFXHandle; pString: PAnsiChar): HRESULT; stdcall;
    function GetString(pName: TCgFXHandle; out ppString: PAnsiChar): HRESULT; stdcall;

    function SetTexture(pName: TCgFXHandle; textureHandle: DWORD): HRESULT; stdcall;
    function GetTexture(pName: TCgFXHandle; out textureHandle: DWORD): HRESULT; stdcall;

    function SetVertexShader(pName: TCgFXHandle; vsHandle: DWORD): HRESULT; stdcall;
    function GetVertexShader(pName: TCgFXHandle; out vsHandle: DWORD): HRESULT; stdcall;

    function SetPixelShader(pName: TCgFXHandle; psHandle: DWORD): HRESULT; stdcall;
    function GetPixelShader(pName: TCgFXHandle; out psHandle: DWORD): HRESULT; stdcall;
  end;

  //todo: add Delphi5 compatibility here...
  CgFXPassFlags = (
    CGFX_DONOTSAVESTATE = 1,
    CGFX_DONOTSAVESHADERSTATE = 2
  );
  {$EXTERNALSYM CgFXPassFlags}
  TCgFXPassFlags = CgFXPassFlags;


  PICgFXEffect = ^ICgFXEffect;
  ICgFXEffect = interface(ICgFXBaseEffect)
    function SetTechnique(pTechnique: TCgFXHandle): HRESULT; stdcall;
    function GetCurrentTechnique: TCgFXHandle; stdcall;

    function ValidateTechnique(technique: TCgFXHandle): HRESULT; stdcall;
    function FindNextValidTechnique(hTechnique: TCgFXHandle; out pTechnique: TCgFXHandle): HRESULT; stdcall;

    function _Begin(pPasses: PLongWord; Flags: DWORD): HRESULT; stdcall;
    function Pass(passNum: LongWord): HRESULT; stdcall;
    function _End: HRESULT; stdcall;

    function CloneEffect(out ppNewEffect: ICgFXEffect): HRESULT; stdcall;

    function GetDevice(out ppDevice: Pointer): HRESULT; stdcall;

    function OnLostDevice: HRESULT; stdcall;
    function OnResetDevice: HRESULT; stdcall;
  end;

  ICgFXEffectCompiler = interface(ICgFXBaseEffect)
    function CompileEffect(const compilerArgs: PPChar; out ppEffect: ICgFXEffect;
                           const ppCompilationErrors: PPChar): HRESULT; stdcall;
  end;


function CgFXCreateEffect(
    pSrcData: PAnsiChar;
    const compilerArguments: PPChar;
    Flags: DWORD;
    out ppEffect: ICgFXEffect;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffect_BCB';
{$EXTERNALSYM CgFXCreateEffect}

function CgFXCreateEffectFromFileA(
    pSrcFile: PAnsiChar;
    const compilerArguments: PPChar;
    out ppEffect: ICgFXEffect;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectFromFileA_BCB';
{$EXTERNALSYM CgFXCreateEffectFromFileA}

function CgFXCreateEffectCompiler(
    pSrcData: PAnsiChar;
    const compilerArguments: PPChar;
    out ppEffectCompiler: ICgFXEffectCompiler;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectCompiler_BCB';
{$EXTERNALSYM CgFXCreateEffectCompiler}

function CgFXCreateEffectCompilerFromFileA(
    pSrcFile: PAnsiChar;
    const compilerArguments: PPChar;
    out ppEffectCompiler: ICgFXEffectCompiler;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectCompilerFromFileA_BCB';
{$EXTERNALSYM CgFXCreateEffectCompilerFromFileA}

function CgFXSetDevice(pDeviceName: PChar; pDevice: Pointer): HResult; cdecl; external CgFX_DLL name 'CgFXSetDevice_BCB';
{$EXTERNALSYM CgFXSetDevice}
function CgFXFreeDevice(pDeviceName: PChar; pDevice: Pointer): HResult; cdecl; external CgFX_DLL name 'CgFXFreeDevice_BCB';
{$EXTERNALSYM CgFXFreeDevice}
function CgFXGetErrors(out ppErrors: PChar): HResult; cdecl; external CgFX_DLL name 'CgFXGetErrors_BCB';
{$EXTERNALSYM CgFXGetErrors}

implementation

end.
